package com.uipath.ml;

import com.amazonaws.*;
import com.amazonaws.auth.AWSStaticCredentialsProvider;
import com.amazonaws.auth.BasicAWSCredentials;
import com.amazonaws.client.builder.AwsClientBuilder;
import com.amazonaws.services.s3.AmazonS3;
import com.amazonaws.services.s3.model.Bucket;
import com.amazonaws.services.s3.model.ListObjectsRequest;
import com.amazonaws.services.s3.model.ObjectListing;
import com.amazonaws.services.s3.model.S3ObjectSummary;

public class AmazonS3ClientBuilder {
    public static void main(String[] args) {
        String accessKey = "XXX";
        String secretKey = "XXX";


        ClientConfiguration clientConfig = new ClientConfiguration();
        clientConfig.setProtocol(Protocol.HTTP);

        BasicAWSCredentials credentials = new BasicAWSCredentials(accessKey, secretKey);
        // S3 Endpoint
        AwsClientBuilder.EndpointConfiguration endpointConfiguration = new
                AwsClientBuilder.EndpointConfiguration("http://XX.XX.XX.XX:39911", "");
        AmazonS3 s3 = com.amazonaws.services.s3.AmazonS3ClientBuilder.standard()
                .withClientConfiguration(clientConfig)
                .withCredentials(new AWSStaticCredentialsProvider(credentials))
                .withEndpointConfiguration(endpointConfiguration)
                .build();

        try {
            /*
             * List of buckets and objects in our account
             */
            System.out.println("Listing buckets and objects");
            for (Bucket bucket : s3.listBuckets()) {
                System.out.println(" - " + bucket.getName() + " "
                        + "(owner = " + bucket.getOwner()
                        + " "
                        + "(creationDate = " + bucket.getCreationDate());
                ObjectListing objectListing = s3.listObjects(new ListObjectsRequest()
                        .withBucketName(bucket.getName()));
                do {
                    for (S3ObjectSummary objectSummary : objectListing.getObjectSummaries()) {
                        System.out.println(" --- " + objectSummary.getKey() + " "
                                + "(size = " + objectSummary.getSize() + ")" + " "
                                + "(eTag = " + objectSummary.getETag() + ")");
                    }
                    objectListing = s3.listNextBatchOfObjects(objectListing);
                } while (objectListing.isTruncated());
            }
        } catch (AmazonServiceException ase) {
            System.out.println("Caught an AmazonServiceException, which means your request made it to S3, but was rejected with an error response for some reason.");
            System.out.println("Error Message:    " + ase.getMessage());
            System.out.println("HTTP Status Code: " + ase.getStatusCode());
            System.out.println("AWS Error Code: " + ase.getErrorCode());
            System.out.println("Error Type: " + ase.getErrorType());
            System.out.println("Request ID: " + ase.getRequestId());
        } catch (AmazonClientException ace) {
            System.out.println("Caught an AmazonClientException, which means the client encountered a serious internal problem while trying to communicate with S3, such as not being able to access the network.");
            System.out.println("Error Message: " + ace.getMessage());
        }
    }
}